summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBastien <bzg@gnu.org>2020-02-19 13:37:17 +0100
committerBastien <bzg@gnu.org>2020-02-19 13:37:17 +0100
commit0b9fcc603f491863f14f087e542c52a83dff08f5 (patch)
treeabd00fdc2cd2373681494702a5fbdff4835d5149
parent26ba4f7d7fa1d920a49394b7d18acd6432d3268d (diff)
downloadorg-mode-0b9fcc603f491863f14f087e542c52a83dff08f5.tar.gz
Revert "org-capture.el: Don't throw an error abusively"
This reverts commit 26ba4f7d7fa1d920a49394b7d18acd6432d3268d.
-rw-r--r--lisp/org-capture.el8
1 files changed, 4 insertions, 4 deletions
diff --git a/lisp/org-capture.el b/lisp/org-capture.el
index 01ecd0e..fac6030 100644
--- a/lisp/org-capture.el
+++ b/lisp/org-capture.el
@@ -1576,11 +1576,11 @@ The template may still contain \"%?\" for cursor positioning."
annotation
(org-capture-get :annotation)
;; When immediately finishing and %a cannot be
;; expanded, warn the user:
(if (org-capture-get :immediate-finish)
- (warn "Missing initial annotation in this template: %s"
- (replace-regexp-in-string
- "\n" " " (org-capture-get :template)))
+ (user-error "Missing initial annotation in this template: %s"
+ (replace-regexp-in-string
+ "\n" " " (org-capture-get :template)))
""))))
;; Is the link empty? Then we do not want it...
(if (equal a "[[]]") "" a)))
@@ -1576,11 +1576,11 @@ The template may still contain \"%?\" for cursor positioning."
(org-capture-get :annotation)
;; When immediately finishing and %a cannot be
- ;; expanded, warn the user:
+ ;; expanded, through a user error:
(if (org-capture-get :immediate-finish)